pub enum MDQueryConditionType {
All,
Any,
}Expand description
Defines the logical operation to apply when combining multiple expressions.
This enum determines how the expressions within an MDQueryCondition are combined:
All: Combines expressions with logical AND (&&)Any: Combines expressions with logical OR (||)
Variants
All
Combines all expressions with logical AND (&&)
Any
Combines all expressions with logical OR (||)